# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_media_closedcaptioning

__all__ = [
    "ClosedCaptionColor",
    "ClosedCaptionEdgeEffect",
    "ClosedCaptionOpacity",
    "ClosedCaptionSize",
    "ClosedCaptionStyle",
    "ClosedCaptionProperties",
]

class ClosedCaptionColor(enum.IntEnum):
    DEFAULT = 0
    WHITE = 1
    BLACK = 2
    RED = 3
    GREEN = 4
    BLUE = 5
    YELLOW = 6
    MAGENTA = 7
    CYAN = 8

class ClosedCaptionEdgeEffect(enum.IntEnum):
    DEFAULT = 0
    NONE = 1
    RAISED = 2
    DEPRESSED = 3
    UNIFORM = 4
    DROP_SHADOW = 5

class ClosedCaptionOpacity(enum.IntEnum):
    DEFAULT = 0
    ONE_HUNDRED_PERCENT = 1
    SEVENTY_FIVE_PERCENT = 2
    TWENTY_FIVE_PERCENT = 3
    ZERO_PERCENT = 4

class ClosedCaptionSize(enum.IntEnum):
    DEFAULT = 0
    FIFTY_PERCENT = 1
    ONE_HUNDRED_PERCENT = 2
    ONE_HUNDRED_FIFTY_PERCENT = 3
    TWO_HUNDRED_PERCENT = 4

class ClosedCaptionStyle(enum.IntEnum):
    DEFAULT = 0
    MONOSPACED_WITH_SERIFS = 1
    PROPORTIONAL_WITH_SERIFS = 2
    MONOSPACED_WITHOUT_SERIFS = 3
    PROPORTIONAL_WITHOUT_SERIFS = 4
    CASUAL = 5
    CURSIVE = 6
    SMALL_CAPITALS = 7

ClosedCaptionProperties = _winrt_windows_media_closedcaptioning.ClosedCaptionProperties



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.ui

from winrt.windows.media.closedcaptioning import ClosedCaptionColor, ClosedCaptionEdgeEffect, ClosedCaptionOpacity, ClosedCaptionSize, ClosedCaptionStyle

Self = typing.TypeVar('Self')

@typing.final
class ClosedCaptionProperties_Static(type):
    def add_properties_changed(cls, handler: winrt.windows.foundation.EventHandler[winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_properties_changed(cls, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def background_color(cls) -> ClosedCaptionColor: ...
    @_property
    def background_opacity(cls) -> ClosedCaptionOpacity: ...
    @_property
    def computed_background_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def computed_font_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def computed_region_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def font_color(cls) -> ClosedCaptionColor: ...
    @_property
    def font_effect(cls) -> ClosedCaptionEdgeEffect: ...
    @_property
    def font_opacity(cls) -> ClosedCaptionOpacity: ...
    @_property
    def font_size(cls) -> ClosedCaptionSize: ...
    @_property
    def font_style(cls) -> ClosedCaptionStyle: ...
    @_property
    def region_color(cls) -> ClosedCaptionColor: ...
    @_property
    def region_opacity(cls) -> ClosedCaptionOpacity: ...

@typing.final
class ClosedCaptionProperties(winrt.system.Object, metaclass=ClosedCaptionProperties_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ClosedCaptionProperties: ...

